exceptiontools.ExtraNoteHeadError
=================================

.. inheritance-diagram:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.ExtraNoteHeadError.ExtraNoteHeadError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
